@@ -79,7 +79,7 @@ seednum=100, epsilon=10^-6, SetID=NULL){
 		out.Z$method.bin="NA"
 		
 		SKATBinary_RestoreSeed(out.seed)
-		
+		class(out.Z)<-"SKATBinary_OUT"
 		return(out.Z)
 	}
 
@@ -98,9 +98,9 @@ seednum=100, epsilon=10^-6, SetID=NULL){
        	is_dosage = is_dosage, missing_cutoff=missing_cutoff, max_maf=max_maf, estimate_MAF=estimate_MAF)	
        	
        	re$method.bin=method.bin
-		if(class(obj) == "SKAT_NULL_Model_ADJ"){
+		if(Check_Class(obj, "SKAT_NULL_Model_ADJ")){
 			re$method.bin="MA"
-		} else if(class(obj) == "SKAT_NULL_Model"){
+		} else if(Check_Class(obj, "SKAT_NULL_Model")){
 			re$method.bin="UA"
 		}
 		
@@ -109,7 +109,7 @@ seednum=100, epsilon=10^-6, SetID=NULL){
 		re$m = m
 		
 		SKATBinary_RestoreSeed(out.seed)
-		
+		class(re)<-"SKATBinary_OUT"
 		return(re)
 	}
 	
@@ -145,7 +145,7 @@ seednum=100, epsilon=10^-6, SetID=NULL){
        	impute.method=impute.method, r.corr=r.corr, is_check_genotype=is_check_genotype,
        	is_dosage = is_dosage, missing_cutoff=missing_cutoff , max_maf=max_maf, estimate_MAF=estimate_MAF)	
 		
-		if (class(obj) == "SKAT_NULL_Model_ADJ") {
+		if (Check_Class(obj, "SKAT_NULL_Model_ADJ")) {
         	method.bin = "MA"
     	} else {
     		method.bin = "UA"
@@ -243,6 +243,7 @@ seednum=100, epsilon=10^-6, SetID=NULL){
 	re$m = m
 		
 	re$method.bin = method.bin
+	class(re)<-"SKATBinary_OUT"
 	return(re)
 	 
 }
@@ -268,6 +269,7 @@ is_check_genotype=TRUE, is_dosage = FALSE, missing_cutoff=0.15, max_maf=1, estim
 	if(out.Z$return==1){
 		
 		SKATBinary_RestoreSeed(out.seed)
+	  class(out.Z)<-"SKATBinary_OUT"
 		return(out.Z)
 	}
 
@@ -314,6 +316,7 @@ is_check_genotype=TRUE, is_dosage = FALSE, missing_cutoff=0.15, max_maf=1, estim
 	SKATBinary_RestoreSeed(out.seed)
 	
 	re$method.bin = method.bin
+	class(re)<-"SKATBinary_OUT"
 	return(re)
 	 
 }
@@ -388,7 +391,7 @@ SKATBinary.SSD.All = function(SSD.INFO, obj, ..., obj.SNPWeight=NULL){
 	for(i in 1:N.Set){
 		Is.Error<-TRUE
 		try1<-try(SKATBinary.SSD.OneSet_SetIndex(SSD.INFO, i, obj, ..., obj.SNPWeight=obj.SNPWeight) ,silent = TRUE)
-		if(class(try1) == "try-error"){
+		if(Is_TryError(try1)){
 			
 				err.msg<-geterrmessage()
 				msg<-sprintf("Error to run SKATBinary for %s: %s",SSD.INFO$SetInfo$SetID[i], err.msg)
